@@ -5,7 +5,7 @@ use warnings;
 use strict;
 use 5.014;
 
-our $VERSION = '2.306';
+our $VERSION = '2.307';
 
 #use bytes; # required
 use Scalar::Util qw( looks_like_number );
@@ -290,143 +290,6 @@ sub primary_key_autoincrement_constraint {
 }
 
 
-sub regexp {
-    my ( $sf, $col, $do_not_match, $case_sensitive ) = @_;
-    if ( $sf->get_db_driver eq 'SQLite' ) {
-        if ( $do_not_match ) {
-            return sprintf " NOT REGEXP(?,%s,%d)", $col, $case_sensitive;
-        }
-        else {
-            return sprintf " REGEXP(?,%s,%d)", $col, $case_sensitive;
-        }
-    }
-    elsif ( $sf->get_db_driver =~ /^(?:mysql|MariaDB)\z/ ) {
-        if ( $do_not_match ) {
-            return " $col NOT REGEXP ?"        if ! $case_sensitive;
-            return " $col NOT REGEXP BINARY ?" if   $case_sensitive;
-        }
-        else {
-            return " $col REGEXP ?"            if ! $case_sensitive;
-            return " $col REGEXP BINARY ?"     if   $case_sensitive;
-        }
-    }
-    elsif ( $sf->get_db_driver eq 'Pg' ) {
-        if ( $do_not_match ) {
-            return " ${col}::text !~* ?" if ! $case_sensitive;
-            return " ${col}::text !~ ?"  if   $case_sensitive;
-        }
-        else {
-            return " ${col}::text ~* ?"  if ! $case_sensitive;
-            return " ${col}::text ~ ?"   if   $case_sensitive;
-        }
-    }
-    elsif ( $sf->get_db_driver eq 'Firebird' ) {
-        # SIMILAR TO
-        # Unlike in some other languages, the pattern must match the entire
-        # string in order to succeed—matching a substring is not enough.
-        # wildcards: '%' and '_'
-        if ( $do_not_match ) {
-            return " $col NOT SIMILAR TO ? ESCAPE '#'";
-        }
-        else {
-            return " $col SIMILAR TO ? ESCAPE '#'";
-        }
-    }
-    elsif ( $sf->get_db_driver =~ /^(?:db2|oracle)\z/ ) {
-        if ( $do_not_match ) {
-            return " NOT REGEXP_LIKE($col,?,'i')" if ! $case_sensitive;
-            return " NOT REGEXP_LIKE($col,?,'c')" if   $case_sensitive;
-        }
-        else {
-            return " REGEXP_LIKE($col,?,'i')"     if ! $case_sensitive;
-            return " REGEXP_LIKE($col,?,'c')"     if   $case_sensitive;
-        }
-    }
-}
-
-
-sub function_with_col {
-    my ( $sf, $func, $col ) = @_;
-    $func = uc( $func );
-    if ( $func eq 'LTRIM' ) {
-        return "TRIM(LEADING FROM $col)"  if $sf->get_db_driver =~ /^(?:Pg|Firebird)\z/;
-        return "LTRIM($col)";
-    }
-    elsif ( $func eq 'RTRIM' ) {
-        return "TRIM(TRAILING FROM $col)" if $sf->get_db_driver =~ /^(?:Pg|Firebird)\z/;
-        return "RTRIM($col)";
-    }
-    else {
-        return "$func($col)";
-    }
-}
-
-
-sub function_with_col_and_arg {
-    my ( $sf, $func, $col, $arg ) = @_;
-    $func = uc( $func );
-    if ( $func eq 'CAST' ) {
-        return "CAST($col AS $arg)";
-    }
-    elsif ( $func eq 'ROUND' ) {
-        return "ROUND($col,$arg)";
-    }
-    elsif ( $func eq 'TRUNCATE' ) {
-        #if ( $sf->get_db_driver eq 'SQLite' ) {
-        #    my $prec_num = '1' . '0' x $arg;
-        #    return "cast( ( $col * $prec_num ) as int ) / $prec_num.0";
-        #}
-        return "TRUNC($col,$arg)"     if $sf->get_db_driver =~ /^(?:Pg|Firebird|oracle)\z/;
-        return "TRUNCATE($col,$arg)";
-    }
-}
-
-
-sub concatenate {
-    my ( $sf, $arguments, $sep ) = @_;
-    my $arg;
-    if ( defined $sep && length $sep ) {
-        my $qt_sep = "'" . $sep . "'";
-        for ( @$arguments ) {
-            push @$arg, $_, $qt_sep;
-        }
-        pop @$arg;
-    }
-    else {
-        $arg = $arguments
-    }
-    return "CONCAT(" . join( ',', @$arg ) . ")"  if $sf->get_db_driver =~ /^(?:mysql|MariaDB)\z/;
-    return join( " || ", @$arg );
-}
-
-
-sub epoch_to_date {
-    my ( $sf, $col, $interval ) = @_;
-    return "DATE($col/$interval,'unixepoch','localtime')"                                  if $sf->get_db_driver eq 'SQLite';
-    return "FROM_UNIXTIME($col/$interval,'%Y-%m-%d')"                                      if $sf->get_db_driver =~ /^(?:mysql|MariaDB)\z/;
-    return "TO_TIMESTAMP(${col}::bigint/$interval)::date"                                  if $sf->get_db_driver eq 'Pg';
-    return "DATEADD(CAST($col AS BIGINT)/$interval SECOND TO DATE '1970-01-01')"           if $sf->get_db_driver eq 'Firebird';
-    return "TIMESTAMP('1970-01-01') + ($col/$interval) SECONDS"                            if $sf->get_db_driver eq 'db2';
-    return "TO_DATE('1970-01-01','YYYY-MM-DD') + NUMTODSINTERVAL($col/$interval,'SECOND')" if $sf->get_db_driver eq 'oracle';
-}
-
-
-sub epoch_to_datetime {
-    my ( $sf, $col, $interval ) = @_;
-    return "DATETIME($col/$interval,'unixepoch','localtime')"                                  if $sf->get_db_driver eq 'SQLite';
-    return "FROM_UNIXTIME($col/$interval,'%Y-%m-%d %H:%i:%s')"                                 if $sf->get_db_driver =~ /^(?:mysql|MariaDB)\z/;        # mysql: FROM_UNIXTIME doesn't work with negative timestamps
-    return "TO_TIMESTAMP(${col}::bigint/$interval)::timestamp"                                 if $sf->get_db_driver eq 'Pg';
-    return "DATEADD(CAST($col AS BIGINT)/$interval SECOND TO TIMESTAMP '1970-01-01 00:00:00')" if $sf->get_db_driver eq 'Firebird';
-    return "TIMESTAMP('1970-01-01 00:00:00') + ($col/$interval) SECONDS"                       if $sf->get_db_driver eq 'db2';
-    return "TO_TIMESTAMP('1970-01-01 00:00:00','YYYY-MM-DD HH24:MI:SS') + NUMTODSINTERVAL($col/$interval,'SECOND')"  if $sf->get_db_driver eq 'oracle';
-}
-
-
-sub replace {
-    my ( $sf, $col, $string_to_replace, $replacement_string ) = @_;
-    return "REPLACE($col,$string_to_replace,$replacement_string)";
-}
-
 # db2 and oracle untested
 
 
@@ -445,7 +308,7 @@ App::DBBrowser::DB - Database plugin documentation.
 
 =head1 VERSION
 
-Version 2.306
+Version 2.307
 
 =head1 DESCRIPTION
 
@@ -693,7 +556,7 @@ Matthäus Kiem <cuer2s@gmail.com>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012-2022 Matthäus Kiem.
+Copyright 2012-2023 Matthäus Kiem.
 
 THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE
 IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
